arXivDaily arXiv每日学术速递 周一至周五更新
arXiv周末暂无论文更新,休息一下吧,周末愉快~~
arXiv 2310.01022cs.ARcs.AI
收藏

基于减法器的CNN推理加速器

Subtractor-Based CNN Inference Accelerator

Dalhousie University(达尔豪斯大学)

Victor Gao, Issam Hammad, Kamal El-Sankary, Jason Gu

AI总结:

本研究提出基于减法器的CNN推理加速方法,通过权重处理将乘加运算替换为减法以降低功耗和面积,可调控性能与精度的权衡,在MNIST数据集上实现了显著的功耗和面积优化且精度损失极低。

摘要:

本文提出了一种利用减法器提升CNN推理加速器性能的新方法。所提出的CNN预处理加速器通过对权重进行排序、分组和舍入,生成特定组合,使得推理阶段执行卷积时,可将一次乘法运算与一次加法运算替换为单次减法运算。鉴于乘法运算在功耗和面积方面成本高昂,用减法替代乘法可通过降低功耗和减少面积实现性能提升。该方法可通过增减减法器的使用量,调控性能增益与精度损失之间的权衡。在舍入大小为0.05的条件下,将该设计搭配LeNet-5模型应用于MNIST数据集,可实现32.03%的功耗节省与24.59%的面积缩减,而精度损失仅为0.1%。

英文摘要:

This paper presents a novel method to boost the performance of CNN inference accelerators by utilizing subtractors. The proposed CNN preprocessing accelerator relies on sorting, grouping, and rounding the weights to create combinations that allow for the replacement of one multiplication operation and addition operation by a single subtraction operation when applying convolution during inference. Given the high cost of multiplication in terms of power and area, replacing it with subtraction allows for a performance boost by reducing power and area. The proposed method allows for controlling the trade-off between performance gains and accuracy loss through increasing or decreasing the usage of subtractors. With a rounding size of 0.05 and by utilizing LeNet-5 with the MNIST dataset, the proposed design can achieve 32.03% power savings and a 24.59% reduction in area at the cost of only 0.1% in terms of accuracy loss.

机构、总结、中文摘要均由AI分析而来,可能存在错误,请以论文正文为准。

↑